@@ -3,6 +3,7 @@ import warnings
 from itertools import chain
 import numpy as np
 import open3d as o3d
+from .. import rotations as pr
 from .. import transformations as pt
 from .. import urdf
 
@@ -89,6 +90,137 @@ class Line3D(Artist):
         return [self.line_set]
 
 
+class PointCollection3D(Artist):
+    """Collection of points.
+
+    Parameters
+    ----------
+    P : array, shape (n_points, 3)
+        Points
+
+    s : float, optional (default: 0.05)
+        Scaling of the spheres that will be drawn.
+
+    c : array-like, shape (3,) or (n_points, 3), optional (default: black)
+        A color is represented by 3 values between 0 and 1 indicate
+        representing red, green, and blue respectively.
+    """
+    def __init__(self, P, s=0.05, c=None):
+        self._points = []
+        self._P = np.zeros_like(P)
+
+        if c is not None:
+            c = np.asarray(c)
+            if c.ndim == 1:
+                c = np.tile(c, (len(P), 1))
+
+        for i in range(len(P)):
+            point = o3d.geometry.TriangleMesh.create_sphere(
+                radius=s, resolution=10)
+            if c is not None:
+                n_vertices = len(point.vertices)
+                colors = np.zeros((n_vertices, 3))
+                colors[:] = c[i]
+                point.vertex_colors = o3d.utility.Vector3dVector(colors)
+            point.compute_vertex_normals()
+            self._points.append(point)
+
+        self.set_data(P)
+
+    def set_data(self, P):
+        """Update data.
+
+        Parameters
+        ----------
+        P : array, shape (n_points, 3)
+            Points
+        """
+        P = np.copy(P)
+        for i, point, p, previous_p in zip(
+                range(len(self._P)), self._points, P, self._P):
+            if any(np.isnan(p)):
+                P[i] = previous_p
+            else:
+                point.translate(p - previous_p)
+
+        self._P = P
+
+    @property
+    def geometries(self):
+        """Expose geometries.
+
+        Returns
+        -------
+        geometries : list
+            List of geometries that can be added to the visualizer.
+        """
+        return self._points
+
+
+class Vector3D(Artist):
+    """A vector.
+
+    Parameters
+    ----------
+    start : array-like, shape (3,), optional (default: [0, 0, 0])
+        Start of the vector
+
+    direction : array-like, shape (3,), optional (default: [1, 0, 0])
+        Direction of the vector
+
+    c : array-like, shape (3,), optional (default: black)
+        A color is represented by 3 values between 0 and 1 indicate
+        representing red, green, and blue respectively.
+    """
+    def __init__(self, start=np.zeros(3), direction=np.array([1, 0, 0]),
+                 c=(0, 0, 0)):
+        self.vector = o3d.geometry.TriangleMesh.create_arrow(
+            cylinder_radius=0.035, cone_radius=0.07,
+            cylinder_height=0.8, cone_height=0.2)
+        self.set_data(start, direction, c)
+
+    def set_data(self, start, direction, c=None):
+        """Update data.
+
+        Parameters
+        ----------
+        start : array-like, shape (3,)
+            Start of the vector
+
+        direction : array-like, shape (3,)
+            Direction of the vector
+
+        c : array-like, shape (3,), optional (default: black)
+            A color is represented by 3 values between 0 and 1 indicate
+            representing red, green, and blue respectively.
+        """
+        length = np.linalg.norm(direction)
+        z = direction / length
+        x, y = pr.plane_basis_from_normal(z)
+        R = np.column_stack((x, y, z))
+        A2B = pt.transform_from(R, start)
+
+        new_vector = o3d.geometry.TriangleMesh.create_arrow(
+            cylinder_radius=0.035 * length, cone_radius=0.07 * length,
+            cylinder_height=0.8 * length, cone_height=0.2 * length)
+        self.vector.vertices = new_vector.vertices
+        self.vector.triangles = new_vector.triangles
+        self.vector.transform(A2B)
+        self.vector.paint_uniform_color(c)
+        self.vector.compute_vertex_normals()
+
+    @property
+    def geometries(self):
+        """Expose geometries.
+
+        Returns
+        -------
+        geometries : list
+            List of geometries that can be added to the visualizer.
+        """
+        return [self.vector]
+
+
 class Frame(Artist):
     """Coordinate frame.
 
@@ -929,7 +1061,18 @@ class Graph(Artist):
 
 
 def _objects_to_artists(objects):
-    """Convert geometries from URDF to artists."""
+    """Convert geometries from URDF to artists.
+
+    Parameters
+    ----------
+    objects : list of Geometry
+        Objects parsed from URDF.
+
+    Returns
+    -------
+    artists : dict
+        Mapping from frame names to artists.
+    """
     artists = {}
     for obj in objects:
         if obj.color is None:
