@@ -4,8 +4,9 @@ import open3d as o3d
 from .. import rotations as pr
 from .. import transformations as pt
 from .. import trajectories as ptr
-from ._artists import (Line3D, Frame, Trajectory, Camera, Box, Sphere,
-                       Cylinder, Mesh, Ellipsoid, Capsule, Cone, Graph)
+from ._artists import (Line3D, PointCollection3D, Vector3D, Frame, Trajectory,
+                       Camera, Box, Sphere, Cylinder, Mesh, Ellipsoid, Capsule,
+                       Cone, Graph)
 
 
 class Figure:
@@ -204,13 +205,62 @@ class Figure:
 
         Returns
         -------
-        Line3D : line
+        line : Line3D
             New line.
         """
         line3d = Line3D(P, c)
         line3d.add_artist(self)
         return line3d
 
+    def scatter(self, P, s=0.05, c=None):
+        """Plot collection of points.
+
+        Parameters
+        ----------
+        P : array, shape (n_points, 3)
+            Points
+
+        s : float, optional (default: 0.05)
+            Scaling of the spheres that will be drawn.
+
+        c : array-like, shape (3,) or (n_points, 3), optional (default: black)
+            A color is represented by 3 values between 0 and 1 indicate
+            representing red, green, and blue respectively.
+
+        Returns
+        -------
+        point_collection : PointCollection3D
+            New point collection.
+        """
+        point_collection = PointCollection3D(P, s, c)
+        point_collection.add_artist(self)
+        return point_collection
+
+    def plot_vector(self, start=np.zeros(3), direction=np.array([1, 0, 0]),
+                    c=(0, 0, 0)):
+        """Plot vector.
+
+        Parameters
+        ----------
+        start : array-like, shape (3,), optional (default: [0, 0, 0])
+            Start of the vector
+
+        direction : array-like, shape (3,), optional (default: [1, 0, 0])
+            Direction of the vector
+
+        c : array-like, shape (3,), optional (default: black)
+            A color is represented by 3 values between 0 and 1 indicate
+            representing red, green, and blue respectively.
+
+        Returns
+        -------
+        vector : Vector3D
+            New vector.
+        """
+        vector3d = Vector3D(start, direction, c)
+        vector3d.add_artist(self)
+        return vector3d
+
     def plot_basis(self, R=None, p=np.zeros(3), s=1.0, strict_check=True):
         """Plot basis.
 
@@ -508,6 +558,11 @@ class Figure:
 
         c : array-like, shape (3,), optional (default: None)
             Color
+
+        Returns
+        -------
+        cone : Cone
+            New cone.
         """
         cone = Cone(height, radius, A2B, resolution, c)
         cone.add_artist(self)
